@@ -18,13 +18,22 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 """
-Standard actions defined in the parce.action module namespace.
+This module defines a fairly large amount of standard actions.
+Most are used by the bundled language definitions and may also be used
+or inherited from by your own language definitions.
+
+The themes built into *parce* also use the names of these standard actions
+to determine the visual appearance of parsed text pieces.
+
+See for a full listing :doc:`stdactions`. See the :mod:`~parce.standardaction`
+module for more information about standard actions.
+
 """
 
 from . import standardaction
 
 # Note: the marked part below of this file is literally shown in the
-# documentation (action.rst)
+# documentation (stdactions.rst)
 
 # BEGIN_ACTIONS
 
@@ -101,8 +110,6 @@ Verbatim        = Literal.Verbatim
 String          = Literal.String        # a quoted string
 Character       = Literal.Character     # a single character
 Number          = Literal.Number        # a numeric value
-Fraction        = Number.Fraction       # a fraction/rational value
-Boolean         = Number.Boolean        # a boolean value
 Literal.Color
 Literal.Email
 Literal.Url
@@ -119,6 +126,20 @@ String.Double
 String.Single
 
 
+# Actions that derive of Number:
+
+Number.Decimal
+Number.Int
+Number.Float
+Number.Binary
+Number.Hexadecimal
+Number.Octal
+Number.Fraction
+Number.Boolean
+Number.Infinity
+Number.NaN
+
+
 # Actions that derive of Delimiter:
 
 Connection      = Delimiter.Connection  # connects things
@@ -132,6 +153,5 @@ Separator       = Delimiter.Separator   # a separator, like \\ or | in LaTeX
 Operator.Assignment                     # e.g. = to denote an assignment
 
 
-del a
 # END_ACTIONS
-del standardaction
+del a, standardaction
