@@ -41,18 +41,14 @@ SKIP_WHITESPACE = (r"\s+", skip)
 
 RE_FRACTION = r"\d+/\d+"
 
-RE_LILYPOND_ID_RIGHT_BOUND = r"(?![_-]?[^\W\d])"
+RE_LILYPOND_ID_RIGHT_BOUND = r"(?![_-]?[^\W\d_])"
 RE_LILYPOND_ID = r"[^\W\d_]+(?:[_-][^\W\d_]+)*"
 RE_LILYPOND_SYMBOL = RE_LILYPOND_ID + RE_LILYPOND_ID_RIGHT_BOUND
 RE_LILYPOND_COMMAND = r"\\(" + RE_LILYPOND_ID + ")" + RE_LILYPOND_ID_RIGHT_BOUND
 RE_LILYPOND_MARKUP_TEXT = r'[^{}"\\\s$#]+'
 RE_LILYPOND_LYRIC_TEXT = r'[^{}"\\\s$#\d]+'
-RE_LILYPOND_DYNAMIC = (
-    r"\\[<!>]|"
-    r"\\(f{1,5}|p{1,5}"
-    r"|mf|mp|fp|spp?|sff?|sfz|rfz"
-    r"|cresc|decresc|dim|cr|decr"
-    r")(?![A-Za-z])")
+RE_LILYPOND_DYNAMIC = \
+    r"\\(?:[<!>]|(?:{})(?![A-Za-z]))".format(words(lilypond_words.dynamics))
 
 RE_LILYPOND_REST = r"[rRs](?![^\W\d])"
 
@@ -62,8 +58,8 @@ RE_LILYPOND_PITCHWORD = r"(?<![^\W\d])[a-zé]+(?:[_-][a-zé]+)*(?![^\W\d_])"
 # a pitch name followed by an optional octave (two capturing groups)
 RE_LILYPOND_PITCH_OCT = "(" + RE_LILYPOND_PITCHWORD + r")\s*('+|,+)?"
 
-RE_LILYPOND_DURATION = \
-    r"(\\(maxima|longa|breve)\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\d))"
+# all durations
+RE_LILYPOND_DURATION = words(lilypond_words.durations, suffix = r'(?!\d)')
 
 
 # Standard actions defined/used here:
@@ -87,6 +83,8 @@ Spanner = Name.Symbol.Spanner
 Spanner.Slur
 Spanner.Ligature
 Spanner.Tie
+Spanner.Id
+Spanner.PesOrFlexa
 Script = Character.Script
 Fingering = Number.Fingering
 
@@ -217,16 +215,19 @@ class LilyPond(Language):
         yield r"\\[()]", Spanner.Slur.Phrasing
         yield r"[()]", Spanner.Slur
         yield r"~", Spanner.Tie
+        yield r"\\~", Spanner.PesOrFlexa
         yield r"[-_^]", Direction, cls.script
+        yield r"(\\=)\s*(?:(\d+)|({}))?".format(RE_LILYPOND_SYMBOL), \
+            bygroup(Spanner.Id, Number, cls.ifpitch(Name.Symbol.Invalid, Name.Symbol))
         yield r"q(?![^\W\d])", Pitch
         yield RE_LILYPOND_REST, Rest
         yield RE_LILYPOND_PITCHWORD, cls.ifpitch((Pitch, cls.pitch))
         yield words(lilypond_words.contexts), Context
         yield words(lilypond_words.grobs), Grob
         yield r'[.,]', Delimiter
-        yield r'(:)\s*(8|16|32|64|128|256|512|1024|2048)(?!\d)', bygroup(Delimiter.Tremolo, Duration.Tremolo)
+        yield r'(:)\s*(8|16|32|64|128|256|512|1024|2048)?(?!\d)', bygroup(Delimiter.Tremolo, Duration.Tremolo)
         yield RE_FRACTION, Number
-        yield RE_LILYPOND_DURATION, Duration, cls.duration_dots
+        yield RE_LILYPOND_DURATION, Duration, cls.duration
         yield r"\d+", Number
         yield from cls.commands()
 
@@ -249,7 +250,7 @@ class LilyPond(Language):
         yield SKIP_WHITESPACE
         yield from cls.common() # markup, scheme, string, comment
         yield RE_LILYPOND_SYMBOL, Name.Symbol
-        yield RE_LILYPOND_DURATION, Duration, cls.duration_dots
+        yield RE_LILYPOND_DURATION, Duration, cls.duration
         yield r"(=)\s*(?:(\d+)(?:\s*(-)\s*(\d+))?)?", bygroup(
             Operator.Assignment, Number, Operator, Number), -1
         yield default_target, -1
@@ -293,6 +294,7 @@ class LilyPond(Language):
         """A script abbreviation or fingering digit."""
         yield r"[+|!>._^-]", Script, -1
         yield r"\d+", Fingering, -1
+        yield SKIP_WHITESPACE
         yield default_target, -1
 
     # ------------------ pitch --------------------------
@@ -308,15 +310,16 @@ class LilyPond(Language):
     @lexicon
     def pitch(cls):
         """A note name, find octave/accidental etc after it."""
-        yield r",+|'+", Octave
+        yield r",(?:\s*?,)*|'(?:\s*?')*", Octave
         yield r"[?!]", Accidental
-        yield r"=(,+|'+)?", OctaveCheck, -1
+        yield r"=(?:,(?:\s*?,)*|'(?:\s*?')*)?", OctaveCheck, -1
         yield SKIP_WHITESPACE
+        yield from cls.find_comment()
         yield default_target, -1
 
     # ------------------ duration ------------------------
     @lexicon
-    def duration_dots(cls):
+    def duration(cls):
         """Zero or more dots after a duration. """
         yield SKIP_WHITESPACE
         yield r'\.', Duration.Dot
@@ -325,7 +328,7 @@ class LilyPond(Language):
 
     @lexicon
     def duration_scaling(cls):
-        """ * n / m after a duration. """
+        """ ``*n/m`` after a duration. """
         yield SKIP_WHITESPACE
         #yield from cls.find_comment()
         yield r"(\*)\s*(\d+(?:/\d+)?)", bygroup(Duration, Duration.Scaling)
@@ -354,7 +357,7 @@ class LilyPond(Language):
                 "_": LyricSkip,
             }, LyricText)
         yield RE_FRACTION, Number
-        yield RE_LILYPOND_DURATION, Duration, cls.duration_dots
+        yield RE_LILYPOND_DURATION, Duration, cls.duration
         yield from cls.commands()
 
     @lexicon(consume=True)
