@@ -221,6 +221,43 @@ markup_commands_nargs = (
 
 markup_commands = sum(markup_commands_nargs, ())
 
+dynamics = (
+    "n",    # niente, since 2.22
+    "ppppp",
+    "pppp",
+    "ppp",
+    "pp",
+    "p",
+    "mp",
+    "mf",
+    "f",
+    "ff",
+    "fff",
+    "ffff",
+    "fffff",
+
+    "fp",
+    "sf",
+    "sfp",
+    "sff",
+    "sfz",
+    "fz",   # undocumented
+    "sp",
+    "spp",
+    "rfz",
+
+    # dynamic spanners:
+    "cr",
+    "decr",
+    "enddecr",
+    "endcr",
+    "cresc",
+    "endcresc",
+    "dim",
+    "enddim",
+    "decresc",
+    "enddecresc",
+)
 
 music_commands = (
     'absolute', # since 2.18
@@ -292,8 +329,6 @@ music_commands = (
     'compoundMeter', # since 2.16
     'compressFullBarRests',
     'context',
-    'cr',
-    'cresc',
     'crescHairpin',
     'crescTextCresc',
     'crossStaff', # since 2.16
@@ -309,7 +344,6 @@ music_commands = (
     'dashPlus',
     'dashUnderscore',
     'deadNote',  # since 2.16
-    'decr',
     'default',
     'defaultNoteHeads',  # since 2.16
     'defaultTimeSignature',
@@ -317,7 +351,6 @@ music_commands = (
     'deminutum',
     'denies',
     'descendens',
-    'dim',
     'dimHairpin',
     'dimTextDecr',
     'dimTextDecresc',
@@ -338,10 +371,6 @@ music_commands = (
     'dynamicUp',
     'easyHeadsOff',
     'easyHeadsOn',
-    'endcr',
-    'endcresc',
-    'enddecr',
-    'enddim',
     'endincipit',
     'endSpanners',
     'episemFinis',
@@ -352,24 +381,17 @@ music_commands = (
     'escapedParenthesisOpenSymbol',
     'escapedSmallerSymbol',
     'expandFullBarRests',
-    'f',
     'featherDurations',
     'fermataMarkup',
-    'ff',
-    'fff',
-    'ffff',
-    'fffff',
     'figuremode',
     'figures',
     'finalis',
     'fingeringOrientations',
     'flexa',
-    'fp',
     'frenchChords',
     'fullJazzExceptions',
     'funkHeads',
     'funkHeadsMinor',
-    'fz',
     'germanChords',
     'glissando',
     'grace',
@@ -422,9 +444,7 @@ music_commands = (
     'mergeDifferentlyDottedOn',
     'mergeDifferentlyHeadedOff',
     'mergeDifferentlyHeadedOn',
-    'mf',
     'mm',
-    'mp',
     'musicMap',
     'neumeDemoLayout',
     'new',
@@ -444,7 +464,6 @@ music_commands = (
     'override',
     'overrideProperty',
     'overrideTimeSignatureSettings',  # since 2.16
-    'p',
     'pageBreak',
     'pageTurn',
     'palmMute',  # since 2.16
@@ -469,10 +488,6 @@ music_commands = (
     'pitchedTrill',
     'pointAndClickOff',
     'pointAndClickOn',
-    'pp',
-    'ppp',
-    'pppp',
-    'ppppp',
     'predefinedFretboardsOff',
     'predefinedFretboardsOn',
     'pt',
@@ -489,7 +504,6 @@ music_commands = (
     'responsum',
     'rest',
     'revert',
-    'rfz',
     'rightHandFinger',
     'sacredHarpHeads',
     'sacredHarpHeadsMinor',
@@ -497,10 +511,6 @@ music_commands = (
     'scoreTweak',
     'semiGermanChords',
     'set',
-    'sf',
-    'sff',
-    'sfp',
-    'sfz',
     'shape', # since 2.16
     'shiftDurations',
     'shiftOff',
@@ -522,16 +532,12 @@ music_commands = (
     'sostenutoOn',
     'southernHarmonyHeads',
     'southernHarmonyHeadsMinor',
-    'sp',
     'spacingTweaks',
-    'spp',
     'startAcciaccaturaMusic',
     'startAppoggiaturaMusic',
     'startGraceMusic',
     'startGroup',
     'startStaff',
-    'startTextSpan',
-    'startTrillSpan',
     'stemDown',
     'stemNeutral',
     'stemUp',
@@ -540,8 +546,6 @@ music_commands = (
     'stopGraceMusic',
     'stopGroup',
     'stopStaff',
-    'stopTextSpan',
-    'stopTrillSpan',
     'stringTuning', # since 2.16
     'strokeFingerOrientations',
     'stropha',
@@ -615,27 +619,32 @@ articulations = (
 
 ornaments = (
     'prall',
-    'mordent',
-    'prallmordent',
-    'turn',
+    'prallup',
+    'pralldown',
     'upprall',
     'downprall',
+    'prallprall',
+    'lineprall',
+    'prallmordent',
+    'mordent',
     'upmordent',
     'downmordent',
-    'lineprall',
-    'prallprall',
-    'pralldown',
-    'prallup',
-    'reverseturn',
     'trill',
+    'turn',
+    'reverseturn',
+    'slashturn',
+    'haydnturn',
 )
 
 
 fermatas = (
+    'veryshortfermata',
     'shortfermata',
     'fermata',
     'longfermata',
     'verylongfermata',
+    'henzeshortfermata',
+    'henzelongfermata',
 )
 
 
@@ -643,15 +652,15 @@ instrument_scripts = (
     'upbow',
     'downbow',
     'flageolet',
-    'thumb',
-    'snappizzicato',
     'open',
     'halfopen',
-    'stopped',
     'lheel',
     'rheel',
     'ltoe',
     'rtoe',
+    'snappizzicato',
+    'stopped',
+    'thumb',
 )
 
 
@@ -663,17 +672,26 @@ repeat_scripts = (
 
 
 ancient_scripts = (
-    'ictus',
     'accentus',
     'circulus',
+    'ictus',
     'semicirculus',
     'signumcongruentiae',
 )
 
 
+# these spanner events are also articulations in LilyPond
+spanner_events = (
+    'startTextSpan',
+    'stopTextSpan',
+    'startTrillSpan',
+    'stopTrillSpan',
+)
+
+
 all_articulations = (
     articulations + ornaments + fermatas + instrument_scripts +
-    repeat_scripts + ancient_scripts
+    repeat_scripts + ancient_scripts + spanner_events
 )
 
 
@@ -1889,3 +1907,8 @@ drum_pitch_names = (
 )
 drum_pitch_names_set = frozenset(drum_pitch_names)
 
+
+durations = (
+    '\\maxima', '\\longa', '\\breve',
+    '1', '2', '4', '8', '16', '32', '64', '128', '256', '512', '1024', '2048',
+)
