@@ -27,12 +27,17 @@ creates a LexiconDescriptor. When a LexiconDescriptor is accessed for the first
 time via a Language subclass, a Lexicon for that class is created and cached,
 and returned each time that attribute is accessed.)
 
+This makes it possible to inherit from a Language class and only re-implement
+some lexicons, the others keep working as in the base class.
+
 The Lexicon can parse text according to the rules. When its :func:`parse`
 function is called for the first time, the rules-function is run with the
 language class as argument, and the rules it yields are cached.
 
-This makes it possible to inherit from a Language class and only re-implement
-some lexicons, the others keep working as in the base class.
+The Lexicon then combines the patterns of the rules into one regular expression
+that is used to parse the text, using some smart optimizations. (For example,
+when a lexicon has only one pattern rule which turns out to be an unambigious
+string, :meth:`str.find` is used rather than using :py:func:`re.search`.)
 
 Example:
 
@@ -127,6 +132,8 @@ class Lexicon:
         :class:`~parce.target.Target` object.
 
     """
+    __hash__ = object.__hash__
+
     def __init__(self, descriptor, language, arg=None):
         #: The LexiconDescriptor this Lexicon was created by.
         self.descriptor = descriptor
@@ -162,9 +169,9 @@ class Lexicon:
         parse time, which is useful for things like here documents, where you
         only get to know the end token after the start token has been found.
 
-        When comparing Lexicons with ``equals()``, a derived lexicon compares
-        equal with the Lexicon that created them, although they co-exist as
-        separate objects.
+        When comparing Lexicons with ``==``, a derived lexicon compares equal
+        with the Lexicon that created it, although they co-exist as separate
+        objects. Use ``is`` to compare on identity.
 
         When yielding the rules from a derived lexicon, the dynamic rule items
         that depend on the Lexicon argument are already evaluated. When
@@ -190,9 +197,17 @@ class Lexicon:
                     lexicon = self._derived[arg] = Lexicon(self.descriptor, self.language, arg)
             return lexicon
 
-    def equals(self, other):
+    def __eq__(self, other):
         """Return True if we are the same lexicon or a derivate from the same."""
-        return self.descriptor is other.descriptor and self.language is other.language
+        return type(other) is type(self) \
+            and self.descriptor is other.descriptor \
+            and self.language is other.language
+
+    def __ne__(self, other):
+        """Return True if we are the not the same lexicon or a derivate from the same."""
+        return type(other) is not type(self) \
+            or self.descriptor is not other.descriptor \
+            or self.language is not other.language
 
     @util.cached_property
     def _rules(self):
@@ -221,11 +236,11 @@ class Lexicon:
         argument are already evaluated.
 
         """
-        yield from self.rules if self.arg else self._rules
+        yield from self.rules if self.arg is not None else self._rules
 
     def __repr__(self):
         s = self.fullname
-        if self.arg:
+        if self.arg is not None:
             s += '*'
         return s
 
