@@ -412,7 +412,7 @@ class Token(Node):
         for c1, c2 in zip(self.ancestors(), other.ancestors()):
             if c1 is c2:
                 return True
-            elif c1.lexicon != c2.lexicon:
+            elif c1.lexicon is not c2.lexicon:
                 return False
         return c1.parent is None and c2.parent is None
 
