@@ -38,8 +38,8 @@ class Dispatcher:
     """Dispatches calls via an instance to methods based on the first argument.
 
     A Dispatcher is used as a decorator when defining a class, and then called
-    via an instance to select a method based on the first argument (which must
-    be hashable).
+    via or in an instance to select a method based on the first argument (which
+    must be hashable).
 
     If you override methods in a subclass that were dispatched, the
     dispatcher automatically dispatches to the new method. If you want to add
@@ -91,14 +91,32 @@ class Dispatcher:
         >>> i.handle_input(3, 10)
         Default function called: 3 10
 
+    To get the method for a key without calling it directly, e.g. to see of
+    a method exists for a key, use::
+
+        >>> meth = i.dispatch.get(1)   # returns a bound method
+        >>> if meth:
+        ...     meth("hi there")
+        ...
+        One called hi there
+
+    If you specified a default method on creation of the dispatcher, that
+    method is also accessible, in the ``default`` attribute::
+
+        >>> i.dispatch.default(1, 2)
+        Default function called: 1 2
 
     """
 
     def __init__(self, default_func=None):
+        self._lock = threading.Lock()
         self._table = {}
         self._tables = weakref.WeakKeyDictionary()
         self._default_func = default_func
 
+    def __set_name__(self, owner, name):
+        self._name = name
+
     def __call__(self, *args):
         def decorator(func):
             for a in args:
@@ -110,38 +128,65 @@ class Dispatcher:
         try:
             table = self._tables[owner]
         except KeyError:
-            # find our name, and find Dispatchers in base classes with same name
-            # if found, inherit their references
-            if self._default_func:
-                mro = iter(owner.mro()[1:])
-                name = self._default_func.__name__
-            else:
-                mro = iter(owner.mro())
-                def get_name():
-                    for c in mro:
-                        for n, v in c.__dict__.items():
-                            if v is self:
-                                return n
-                name = get_name()
-            dispatchers = []
-            for c in mro:
-                d = c.__dict__.get(name)
-                if type(d) is type(self):
-                    dispatchers.append(d)
-            _table = {}
-            for d in reversed(dispatchers):
-                _table.update(d._table)
-            _table.update(self._table)
-            # now, store the actual functions instead of their names
-            table = self._tables[owner] = {a: getattr(owner, name)
-                        for a, name in _table.items()}
-        def func(key, *args, **kwargs):
-            f = table.get(key)
-            if f:
-                return f(instance, *args, **kwargs)
-            if self._default_func:
-                return self._default_func(instance, key, *args, **kwargs)
-        return func
+            with self._lock:
+                try:
+                    table = self._tables[owner]
+                except KeyError:
+                    # find Dispatchers in base classes with the same name
+                    # if found, inherit their references
+                    dispatchers = []
+                    for c in owner.mro():
+                        d = c.__dict__.get(self._name)
+                        if type(d) is type(self):
+                            dispatchers.append(d)
+                    _table = {}
+                    for d in reversed(dispatchers):
+                        _table.update(d._table)
+                    # now, store the actual functions instead of their names
+                    table = self._tables[owner] = {a: getattr(owner, name)
+                                for a, name in _table.items()}
+        return _Dispatcher(self, table, instance, owner)
+
+
+class _Dispatcher:
+    """Helper class for Dispatcher."""
+    __slots__ = ("_dispatcher", "_table", "_instance", "_owner")
+    def __init__(self, dispatcher, table, instance, owner):
+        self._dispatcher = dispatcher
+        self._table = table
+        self._instance = instance
+        self._owner = owner
+
+    def __repr__(self):
+        return "<{}.{} {}.{} of {}>".format(
+            self._dispatcher.__class__.__module__,
+            self._dispatcher.__class__.__name__,
+            self._owner.__name__,
+            self._dispatcher._name,
+            repr(self._instance))
+
+    def __call__(self, key, *args, **kwargs):
+        """Call the stored method based on the key (first argument) with the
+        other arguments."""
+        f = self._table.get(key)
+        if f:
+            return f(self._instance, *args, **kwargs)
+        f = self.default
+        if f:
+            return f(key, *args, **kwargs)
+
+    @property
+    def default(self):
+        """The bound method specified as default, if any."""
+        f = self._dispatcher._default_func
+        if f:
+            return f.__get__(self._instance, self._owner)
+
+    def get(self, key):
+        """Return the bound method for the key, without calling it."""
+        f = self._table.get(key)
+        if f:
+            return f.__get__(self._instance, self._owner)
 
 
 class _Observer:
